@@ -40,7 +40,6 @@ template '/linklist.html' => sub {
                 ["Currency", "/currency"],
                 ["Foo", "/foo"],
             );
-
         }
     };
 };
@@ -54,5 +53,10 @@ template '/var-in-attribute.html' => sub {
     }
 };
 
+template '/perlbuiltin.html' => sub {
+    html_q { "Here is a short quotation here is a short quotation" };
+};
+
+
 1;
 
